"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ivi_1 = require("ivi");
const ATTRIBUTE_DIRECTIVE_SET_XML_ATTR_EMPTY = {
    v: "",
    u: updateXMLAttr,
};
const ATTRIBUTE_DIRECTIVE_SET_XLINK_ATTR_EMPTY = {
    v: "",
    u: updateXLinkAttr,
};
function updateNSAttr(element, ns, key, prev, next) {
    if (prev !== next) {
        if (next === void 0) {
            ivi_1.elementRemoveAttribute.call(element, key);
        }
        else {
            ivi_1.elementSetAttributeNS.call(element, ns, key, next);
        }
    }
}
/**
 * Update function for an {@link AttributeDirective} created with {@link XML_ATTR} function.
 *
 * @param element - Target element
 * @param key - Attribute key
 * @param prev - Previous value
 * @param next - Next value
 */
function updateXMLAttr(element, key, prev, next) {
    updateNSAttr(element, ivi_1.XML_NAMESPACE, key, prev, next);
}
/**
 * Update function for an {@link AttributeDirective} created with {@link XLINK_ATTR} function.
 *
 * @param element - Target element
 * @param key - Attribute key
 * @param prev - Previous value
 * @param next - Next value
 */
function updateXLinkAttr(element, key, prev, next) {
    updateNSAttr(element, ivi_1.XLINK_NAMESPACE, key, prev, next);
}
/**
 * XML_ATTR function creates an {@link AttributeDirective} that assigns an attribute from XML namespace, attribute name
 * is derived from the `key`.
 *
 * @example
 *
 *   const e = circle("", { "xml:text": XML_ATTR("abc") });
 *
 * @param v Value.
 * @returns {@link AttributeDirective}
 */
exports.XML_ATTR = (v) => (v === "" ? ATTRIBUTE_DIRECTIVE_SET_XML_ATTR_EMPTY : { v, u: updateXMLAttr });
/**
 * XLINK_ATTR function creates an {@link AttributeDirective} that assigns an attribute from XLINK namespace, attribute
 * name is derived from the `key`.
 *
 * @example
 *
 *   const e = circle("", { "xlink:text": XLINK_ATTR("abc") });
 *
 * @param v Value.
 * @returns {@link AttributeDirective}
 */
exports.XLINK_ATTR = (v) => (v === "" ? ATTRIBUTE_DIRECTIVE_SET_XLINK_ATTR_EMPTY : { v, u: updateXLinkAttr });
/* tslint:disable:max-line-length */
/**
 * Creates OpNode SVG element <a>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/a}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <a>
 */
exports.a = ivi_1.svgElementFactory("a");
/**
 * Creates OpNode SVG element <animate>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animate}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <animate>
 */
exports.animate = ivi_1.svgElementFactory("animate");
/**
 * Creates OpNode SVG element <animateColor>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateColor}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <animateColor>
 */
exports.animateColor = ivi_1.svgElementFactory("animateColor");
/**
 * Creates OpNode SVG element <animateMotion>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateMotion}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <animateMotion>
 */
exports.animateMotion = ivi_1.svgElementFactory("animateMotion");
/**
 * Creates OpNode SVG element <animateTransform>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animateTransform}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <animateTransform>
 */
exports.animateTransform = ivi_1.svgElementFactory("animateTransform");
/**
 * Creates OpNode SVG element <circle>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/circle}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <circle>
 */
exports.circle = ivi_1.svgElementFactory("circle");
/**
 * Creates OpNode SVG element <clipPath>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/clipPath}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <clipPath>
 */
exports.clipPath = ivi_1.svgElementFactory("clipPath");
/**
 * Creates OpNode SVG element <defs>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/defs}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <defs>
 */
exports.defs = ivi_1.svgElementFactory("defs");
/**
 * Creates OpNode SVG element <desc>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/desc}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <desc>
 */
exports.desc = ivi_1.svgElementFactory("desc");
/**
 * Creates OpNode SVG element <ellipse>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/ellipse}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <ellipse>
 */
exports.ellipse = ivi_1.svgElementFactory("ellipse");
/**
 * Creates OpNode SVG element <feBlend>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feBlend}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feBlend>
 */
exports.feBlend = ivi_1.svgElementFactory("feBlend");
/**
 * Creates OpNode SVG element <feColorMatrix>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feColorMatrix}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feColorMatrix>
 */
exports.feColorMatrix = ivi_1.svgElementFactory("feColorMatrix");
/**
 * Creates OpNode SVG element <feComponentTransfer>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComponentTransfer}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feComponentTransfer>
 */
exports.feComponentTransfer = ivi_1.svgElementFactory("feComponentTransfer");
/**
 * Creates OpNode SVG element <feComposite>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComposite}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feComposite>
 */
exports.feComposite = ivi_1.svgElementFactory("feComposite");
/**
 * Creates OpNode SVG element <feConvolveMatrix>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feConvolveMatrix}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feConvolveMatrix>
 */
exports.feConvolveMatrix = ivi_1.svgElementFactory("feConvolveMatrix");
/**
 * Creates OpNode SVG element <feDiffuseLighting>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDiffuseLighting}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feDiffuseLighting>
 */
exports.feDiffuseLighting = ivi_1.svgElementFactory("feDiffuseLighting");
/**
 * Creates OpNode SVG element <feDisplacementMap>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDisplacementMap}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feDisplacementMap>
 */
exports.feDisplacementMap = ivi_1.svgElementFactory("feDisplacementMap");
/**
 * Creates OpNode SVG element <feDistantLight>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDistantLight}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feDistantLight>
 */
exports.feDistantLight = ivi_1.svgElementFactory("feDistantLight");
/**
 * Creates OpNode SVG element <feDropShadow>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDropShadow}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feDropShadow>
 */
exports.feDropShadow = ivi_1.svgElementFactory("feDropShadow");
/**
 * Creates OpNode SVG element <feFlood>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFlood}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feFlood>
 */
exports.feFlood = ivi_1.svgElementFactory("feFlood");
/**
 * Creates OpNode SVG element <feFuncA>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncA}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feFuncA>
 */
exports.feFuncA = ivi_1.svgElementFactory("feFuncA");
/**
 * Creates OpNode SVG element <feFuncB>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncB}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feFuncB>
 */
exports.feFuncB = ivi_1.svgElementFactory("feFuncB");
/**
 * Creates OpNode SVG element <feFuncG>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncG}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feFuncG>
 */
exports.feFuncG = ivi_1.svgElementFactory("feFuncG");
/**
 * Creates OpNode SVG element <feFuncR>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncR}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feFuncR>
 */
exports.feFuncR = ivi_1.svgElementFactory("feFuncR");
/**
 * Creates OpNode SVG element <feGaussianBlur>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feGaussianBlur}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feGaussianBlur>
 */
exports.feGaussianBlur = ivi_1.svgElementFactory("feGaussianBlur");
/**
 * Creates OpNode SVG element <feImage>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feImage}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feImage>
 */
exports.feImage = ivi_1.svgElementFactory("feImage");
/**
 * Creates OpNode SVG element <feMerge>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMerge}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feMerge>
 */
exports.feMerge = ivi_1.svgElementFactory("feMerge");
/**
 * Creates OpNode SVG element <feMergeNode>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMergeNode}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feMergeNode>
 */
exports.feMergeNode = ivi_1.svgElementFactory("feMergeNode");
/**
 * Creates OpNode SVG element <feMorphology>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMorphology}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feMorphology>
 */
exports.feMorphology = ivi_1.svgElementFactory("feMorphology");
/**
 * Creates OpNode SVG element <feOffset>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feOffset}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feOffset>
 */
exports.feOffset = ivi_1.svgElementFactory("feOffset");
/**
 * Creates OpNode SVG element <fePointLight>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/fePointLight}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <fePointLight>
 */
exports.fePointLight = ivi_1.svgElementFactory("fePointLight");
/**
 * Creates OpNode SVG element <feSpecularLighting>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpecularLighting}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feSpecularLighting>
 */
exports.feSpecularLighting = ivi_1.svgElementFactory("feSpecularLighting");
/**
 * Creates OpNode SVG element <feSpotLight>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpotLight}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feSpotLight>
 */
exports.feSpotLight = ivi_1.svgElementFactory("feSpotLight");
/**
 * Creates OpNode SVG element <feTile>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTile}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feTile>
 */
exports.feTile = ivi_1.svgElementFactory("feTile");
/**
 * Creates OpNode SVG element <feTurbulence>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTurbulence}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <feTurbulence>
 */
exports.feTurbulence = ivi_1.svgElementFactory("feTurbulence");
/**
 * Creates OpNode SVG element <filter>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/filter}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <filter>
 */
exports.filter = ivi_1.svgElementFactory("filter");
/**
 * Creates OpNode SVG element <foreignObject>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/foreignObject}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <foreignObject>
 */
exports.foreignObject = ivi_1.svgElementFactory("foreignObject");
/**
 * Creates OpNode SVG element <g>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/g}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <g>
 */
exports.g = ivi_1.svgElementFactory("g");
/**
 * Creates OpNode SVG element <hatch>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatch}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <hatch>
 */
exports.hatch = ivi_1.svgElementFactory("hatch");
/**
 * Creates OpNode SVG element <hatchpath>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/hatchpath}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <hatchpath>
 */
exports.hatchpath = ivi_1.svgElementFactory("hatchpath");
/**
 * Creates OpNode SVG element <image>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/image}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <image>
 */
exports.image = ivi_1.svgElementFactory("image");
/**
 * Creates OpNode SVG element <line>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/line}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <line>
 */
exports.line = ivi_1.svgElementFactory("line");
/**
 * Creates OpNode SVG element <linearGradient>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/linearGradient}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <linearGradient>
 */
exports.linearGradient = ivi_1.svgElementFactory("linearGradient");
/**
 * Creates OpNode SVG element <marker>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/marker}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <marker>
 */
exports.marker = ivi_1.svgElementFactory("marker");
/**
 * Creates OpNode SVG element <mask>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mask}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <mask>
 */
exports.mask = ivi_1.svgElementFactory("mask");
/**
 * Creates OpNode SVG element <mesh>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mesh}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <mesh>
 */
exports.mesh = ivi_1.svgElementFactory("mesh");
/**
 * Creates OpNode SVG element <meshgradient>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/meshgradient}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <meshgradient>
 */
exports.meshgradient = ivi_1.svgElementFactory("meshgradient");
/**
 * Creates OpNode SVG element <meshpatch>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/meshpatch}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <meshpatch>
 */
exports.meshpatch = ivi_1.svgElementFactory("meshpatch");
/**
 * Creates OpNode SVG element <meshrow>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/meshrow}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <meshrow>
 */
exports.meshrow = ivi_1.svgElementFactory("meshrow");
/**
 * Creates OpNode SVG element <metadata>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/metadata}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <metadata>
 */
exports.metadata = ivi_1.svgElementFactory("metadata");
/**
 * Creates OpNode SVG element <mpath>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mpath}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <mpath>
 */
exports.mpath = ivi_1.svgElementFactory("mpath");
/**
 * Creates OpNode SVG element <path>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/path}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <path>
 */
exports.path = ivi_1.svgElementFactory("path");
/**
 * Creates OpNode SVG element <pattern>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/pattern}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <pattern>
 */
exports.pattern = ivi_1.svgElementFactory("pattern");
/**
 * Creates OpNode SVG element <polygon>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polygon}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <polygon>
 */
exports.polygon = ivi_1.svgElementFactory("polygon");
/**
 * Creates OpNode SVG element <polyline>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polyline}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <polyline>
 */
exports.polyline = ivi_1.svgElementFactory("polyline");
/**
 * Creates OpNode SVG element <radialGradient>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/radialGradient}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <radialGradient>
 */
exports.radialGradient = ivi_1.svgElementFactory("radialGradient");
/**
 * Creates OpNode SVG element <rect>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/rect}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <rect>
 */
exports.rect = ivi_1.svgElementFactory("rect");
/**
 * Creates OpNode SVG element <set>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/set}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <set>
 */
exports.set = ivi_1.svgElementFactory("set");
/**
 * Creates OpNode SVG element <solidcolor>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/solidcolor}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <solidcolor>
 */
exports.solidcolor = ivi_1.svgElementFactory("solidcolor");
/**
 * Creates OpNode SVG element <stop>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/stop}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <stop>
 */
exports.stop = ivi_1.svgElementFactory("stop");
/**
 * Creates OpNode SVG element <svg>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <svg>
 */
exports.svg = ivi_1.svgElementFactory("svg");
/**
 * Creates OpNode SVG element <symbol>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/symbol}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <symbol>
 */
exports.symbol = ivi_1.svgElementFactory("symbol");
/**
 * Creates OpNode SVG element <text>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/text}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <text>
 */
exports.text = ivi_1.svgElementFactory("text");
/**
 * Creates OpNode SVG element <textPath>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/textPath}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <textPath>
 */
exports.textPath = ivi_1.svgElementFactory("textPath");
/**
 * Creates OpNode SVG element <title>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/title}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <title>
 */
exports.title = ivi_1.svgElementFactory("title");
/**
 * Creates OpNode SVG element <tspan>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/tspan}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <tspan>
 */
exports.tspan = ivi_1.svgElementFactory("tspan");
/**
 * Creates OpNode SVG element <use>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/use}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <use>
 */
exports.use = ivi_1.svgElementFactory("use");
/**
 * Creates OpNode SVG element <view>.
 *
 * {@link https://developer.mozilla.org/en-US/docs/Web/SVG/Element/view}
 *
 * @param className Class name.
 * @param attrs Attributes.
 * @param children Children nodes.
 * @returns OpNode SVG element <view>
 */
exports.view = ivi_1.svgElementFactory("view");
//# sourceMappingURL=index.js.map